@@ -525,6 +525,7 @@ as_ggplot <- function(scplot) {
         "mean", "median", "min", "max", "quantile", "sd", "mad"
       )
       if (scplot$statlines[[j]]$stat %in% .constant_stats) {
+
         p <- p + .statline_constant(
           data_long,
           line = scplot$statlines[[j]],
@@ -693,7 +694,7 @@ as_ggplot <- function(scplot) {
         data = dat,
         mapping = aes(x = x0, y = y0, xend = x1, yend = y1),
         colour = scplot$lines[[i]]$colour,
-        size = scplot$lines[[i]]$size,
+        linewidth = scplot$lines[[i]]$linewidth,
         arrow = arrow_par
       )
     }
