@@ -21,12 +21,13 @@ add_title <- function(object, label,...) {
 }
 
 #' @rdname add_title
+#' @param header String with header above footnote/ caption
 #' @export
-add_caption <- function(object, label, ...) {
+add_caption <- function(object, label, header = "Note:\n", ...) {
 
   args <- list(...)
   if (missing(label)) label <- ""
-  object$caption <- label
+  object$caption <- paste0(header, paste0(label, collapse = "\n"))
 
   if (!is.null(args$size)) args$size <- rel(args$size)
 
